==> kernel-1.8.0-alpha1-sources.jar: com/flybits/android/kernel/deserializers/DeserializeContentInstance.java <==
package com.flybits.android.kernel.deserializers;

import android.content.Context;
import android.support.annotation.NonNull;

import com.flybits.android.kernel.models.Content;
import com.flybits.android.kernel.models.SurveyMetadata;
import com.flybits.commons.library.SharedElements;
import com.flybits.commons.library.deserializations.IDeserializer;
import com.flybits.commons.library.logging.Logger;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Iterator;

public class DeserializeContentInstance extends IDeserializer<Content>{

    private Context mContext;

    public DeserializeContentInstance(@NonNull Context context)
    {
        mContext = context;
    }

    @Override
    public String toJson(Content contentResponse) {
        JSONObject object = new JSONObject();

        JSONObject localizationObject   = new JSONObject();
        ArrayList<String> listofCodes   = new ArrayList<>();
        for (String code : contentResponse.getNameObject().getListOfSupportedLanguages()){

            try {
                if (contentResponse.getName(code) != null) {

                    listofCodes.add(code);
                    JSONObject objectLanguageCode   = new JSONObject();
                    objectLanguageCode.put("name", contentResponse.getName(code));
                    localizationObject.put(code, objectLanguageCode);

                    if (contentResponse.getDescription(code) != null) {
                        objectLanguageCode.put("description", contentResponse.getDescription(code));
                        localizationObject.put(code, objectLanguageCode);
                    }
                }
            } catch (JSONException e) {Logger.exception("DeserializeContentInstance.toJson", e);}
        }

        for (String code : contentResponse.getDescriptionObject().getListOfSupportedLanguages()){

            try {
                if (!listofCodes.contains(code) && contentResponse.getDescription(code) != null) {
                    JSONObject objectLanguageCode   = new JSONObject();
                    objectLanguageCode.put("description", contentResponse.getDescription(code));
                    localizationObject.put(code, objectLanguageCode);
                }
            } catch (JSONException e) {Logger.exception("DeserializeContentInstance.toJson", e);}
        }

        try {
            object.put("localizations", localizationObject);
            if (contentResponse.getIcon() != null) {
                object.put("iconUrl", contentResponse.getIcon());
            }
            object.put("templateId", contentResponse.getTemplateId());
            object.put("templateType", contentResponse.getType());
        } catch (JSONException e) {
            Logger.exception("DeserializeContentInstance.toJson", e);}

        return object.toString();
    }

    @Override
    public Content fromJson(JSONObject jsonObject) {
        try {
            String id = jsonObject.getString("id");
            String templateId = jsonObject.getString("templateId");
            long createdAt = -1;
            if (!jsonObject.isNull("createdAt")) {
                createdAt   = jsonObject.getLong("createdAt");
            }
            long modifiedAt = -1;
            if (!jsonObject.isNull("modifiedAt")) {
                modifiedAt   = jsonObject.getLong("modifiedAt");
            }

            String iconUrl = null;
            if (!jsonObject.isNull("iconUrl")) {
                iconUrl = jsonObject.getString("iconUrl");
            }

            String type = null;
            if (!jsonObject.isNull("templateType")) {
                type = jsonObject.getString("templateType");
            }

            JSONObject dataContainer = jsonObject.optJSONObject("content");

            String data = null;
            if (dataContainer != null) {
                data = dataContainer.toString();
            }

            ArrayList<String> labels    = new ArrayList<>();
            if (!jsonObject.isNull("labels")){
                JSONArray jsonArray = jsonObject.getJSONArray("labels");
                for (int i = 0; i < jsonArray.length(); i++){
                    labels.add(jsonArray.getString(i));
                }
            }

            Content instance = new Content(id, templateId, iconUrl, "en", SharedElements.get(mContext).getEnabledLanguagesAsString(),
                    createdAt, modifiedAt, data, labels, type);

            if (!jsonObject.isNull("localizations")){

                JSONObject localizationObject   = jsonObject.getJSONObject("localizations");
                Iterator<String> languages      = localizationObject.keys();

                while (languages.hasNext()){

                    String language             = languages.next();
                    JSONObject languageObj      = localizationObject.getJSONObject(language);
                    if (!languageObj.isNull("description")){
                        instance.setDescription(language, languageObj.getString("description"));
                    }

                    if (!languageObj.isNull("name")){
                        instance.setName(language, languageObj.getString("name"));
                    }
                }
            }

            if (!jsonObject.isNull("surveyMetadata")) {
                JSONObject surveyMetadata = jsonObject.optJSONObject("surveyMetadata");
                SurveyMetadata obj = new SurveyMetadata(surveyMetadata);
                instance.setMetadata(obj);
            }

            return instance;
        } catch (JSONException e) {
            Logger.exception("DeserializeContentInstance.fromJson", e);
        }
        return null;
    }

    @Override
    public Content fromJson(JSONArray jsonArray) {
        return null;
    }
}

==> kernel-1.10.0-alpha1-sources.jar: com/flybits/android/kernel/deserializers/DeserializeContentInstance.java <==
package com.flybits.android.kernel.deserializers;

import android.content.Context;
import android.support.annotation.NonNull;

import com.flybits.android.kernel.models.Content;
import com.flybits.android.kernel.models.SurveyMetadata;
import com.flybits.commons.library.SharedElementsFactory;
import com.flybits.commons.library.deserializations.IDeserializer;
import com.flybits.commons.library.logging.Logger;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.Iterator;

public class DeserializeContentInstance extends IDeserializer<Content>{

    private Context mContext;

    public DeserializeContentInstance(@NonNull Context context)
    {
        mContext = context;
    }

    @Override
    public String toJson(Content contentResponse) {
        JSONObject object = new JSONObject();

        JSONObject localizationObject   = new JSONObject();
        ArrayList<String> listofCodes   = new ArrayList<>();
        for (String code : contentResponse.getNameObject().getListOfSupportedLanguages()){

            try {
                if (contentResponse.getName(code) != null) {

                    listofCodes.add(code);
                    JSONObject objectLanguageCode   = new JSONObject();
                    objectLanguageCode.put("name", contentResponse.getName(code));
                    localizationObject.put(code, objectLanguageCode);

                    if (contentResponse.getDescription(code) != null) {
                        objectLanguageCode.put("description", contentResponse.getDescription(code));
                        localizationObject.put(code, objectLanguageCode);
                    }
                }
            } catch (JSONException e) {Logger.exception("DeserializeContentInstance.toJson", e);}
        }

        for (String code : contentResponse.getDescriptionObject().getListOfSupportedLanguages()){

            try {
                if (!listofCodes.contains(code) && contentResponse.getDescription(code) != null) {
                    JSONObject objectLanguageCode   = new JSONObject();
                    objectLanguageCode.put("description", contentResponse.getDescription(code));
                    localizationObject.put(code, objectLanguageCode);
                }
            } catch (JSONException e) {Logger.exception("DeserializeContentInstance.toJson", e);}
        }

        try {
            object.put("localizations", localizationObject);
            if (contentResponse.getIcon() != null) {
                object.put("iconUrl", contentResponse.getIcon());
            }
            object.put("templateId", contentResponse.getTemplateId());
            object.put("templateType", contentResponse.getType());
        } catch (JSONException e) {
            Logger.exception("DeserializeContentInstance.toJson", e);}

        return object.toString();
    }

    @Override
    public Content fromJson(JSONObject jsonObject) {
        try {
            String id = jsonObject.getString("id");
            String templateId = jsonObject.getString("templateId");
            long createdAt = -1;
            if (!jsonObject.isNull("createdAt")) {
                createdAt   = jsonObject.getLong("createdAt");
            }
            long modifiedAt = -1;
            if (!jsonObject.isNull("modifiedAt")) {
                modifiedAt   = jsonObject.getLong("modifiedAt");
            }

            String iconUrl = null;
            if (!jsonObject.isNull("iconUrl")) {
                iconUrl = jsonObject.getString("iconUrl");
            }

            String type = null;
            if (!jsonObject.isNull("templateType")) {
                type = jsonObject.getString("templateType");
            }

            JSONObject dataContainer = jsonObject.optJSONObject("content");

            String data = null;
            if (dataContainer != null) {
                data = dataContainer.toString();
            }

            ArrayList<String> labels    = new ArrayList<>();
            if (!jsonObject.isNull("labels")){
                JSONArray jsonArray = jsonObject.getJSONArray("labels");
                for (int i = 0; i < jsonArray.length(); i++){
                    labels.add(jsonArray.getString(i));
                }
            }

            Content instance = new Content(id, templateId, iconUrl, "en", SharedElementsFactory.INSTANCE.get(mContext).getEnabledLanguagesAsString(),
                    createdAt, modifiedAt, data, labels, type);

            if (!jsonObject.isNull("localizations")){

                JSONObject localizationObject   = jsonObject.getJSONObject("localizations");
                Iterator<String> languages      = localizationObject.keys();

                while (languages.hasNext()){

                    String language             = languages.next();
                    JSONObject languageObj      = localizationObject.getJSONObject(language);
                    if (!languageObj.isNull("description")){
                        instance.setDescription(language, languageObj.getString("description"));
                    }

                    if (!languageObj.isNull("name")){
                        instance.setName(language, languageObj.getString("name"));
                    }
                }
            }

            if (!jsonObject.isNull("surveyMetadata")) {
                JSONObject surveyMetadata = jsonObject.optJSONObject("surveyMetadata");
                SurveyMetadata obj = new SurveyMetadata(surveyMetadata);
                instance.setMetadata(obj);
            }

            return instance;
        } catch (JSONException e) {
            Logger.exception("DeserializeContentInstance.fromJson", e);
        }
        return null;
    }

    @Override
    public Content fromJson(JSONArray jsonArray) {
        return null;
    }
}
